@@ -28,6 +28,9 @@
 #include <QQueue>
 #include <QTimer>
 #include <QNetworkReply>
+#include <QScopedPointer>
+
+class QFile;
 
 namespace KGAPI2 {
 
@@ -38,6 +41,23 @@ struct Request
     QString contentType;
 };
 
+class Q_DECL_HIDDEN FileLogger
+{
+public:
+    ~FileLogger();
+
+    static FileLogger *self();
+
+    void logRequest(const Request &request);
+    void logReply(const QNetworkReply *reply, const QByteArray &rawData);
+
+private:
+    FileLogger();
+    QScopedPointer<QFile> mFile;
+
+    static FileLogger *sInstance;
+};
+
 class Q_DECL_HIDDEN Job::Private
 {
   public:
