@@ -54,7 +54,9 @@ class KGAPITASKS_EXPORT TaskList: public KGAPI2::Object
     /**
      * @brief Destructor
      */
-    virtual ~TaskList();
+    ~TaskList() override;
+
+    bool operator==(const TaskList &other) const;
 
     /**
      * @brief Sets tasklist UID
